#@+leo-ver=4
#@+node:@file examples/fltk/setup.py
# remove this statement when you're happy with your settings

raise Exception("Please tweak this setup script for your environment")


# python imports
import sys


# usual Pyrex imports

from distutils.core import setup, Extension
from Pyrex.Distutils import build_ext


# grab our pyrexembed processor

import pyrexembed


# the sources going into the extension
# note that you're including pyfltklite.pyx, not pyfltklite.pyxe

sources = ['pyfltklite.pyx', 'pyfltklite_embed.cpp']


# grotty platform-specifics - you may need to tweak these

if sys.platform.lower().find("linux") >= 0:

    # linux compilation - hack distutils to use 'g++' for link
    # instead of gcc - otherwise loading the extension might
    # fail with an '_Znwj unresolved symbol'
    pyrexembed.linkwithgplusplus()

if '--compiler=mingw32' in sys.argv:
    mingw = True
else:
    mingw = False

incDirs = []
libs = []
libDirs = []
runtimeLibDirs = []
cMacros = []

extraLinkArgs = [] # shared

if sys.platform == 'win32':
    libs = []
    extraLinkArgs = ['libfltk.a']
else:
    # non-windows
    libs = ['X11', 'fltk']
    libDirs = ['/usr/lib', '/usr/local/lib', '/usr/X11R6/lib']


# spec out the extension module

pyfltkLite = Extension('pyfltklite',
                        sources,
                        define_macros=cMacros,
                        include_dirs=incDirs,
                        libraries=libs,
                        library_dirs=libDirs,
                        runtime_library_dirs=runtimeLibDirs,
                        extra_compile_args=['-g'],
                        extra_link_args=extraLinkArgs
                        )


# process the .pyxe file

pyrexembed.process("pyfltklite.pyxe")


# and build the extension

setup(name = 'pyfltklite',
      version = '1.0',
      description = 'Hand-written FLTK wrapper',
      ext_modules = [pyfltkLite],
      cmdclass = {'build_ext': build_ext},
      )

#@-node:@file examples/fltk/setup.py
#@-leo
